Dask-ML
=======

|Build Status| |Azure Pipelines| |Coverage| |Doc Status| |Discourse| |Version Status| |NumFOCUS|

Dask-ML provides scalable machine learning in Python using `Dask <https://dask.org/>`__ alongside popular machine learning libraries like `Scikit-Learn <http://scikit-learn.org/>`__, `XGBoost <https://ml.dask.org/xgboost.html>`__, and others.

You can try Dask-ML on a small cloud instance by clicking the following button:

.. image:: https://mybinder.org/badge.svg
   :target: https://mybinder.org/v2/gh/dask/dask-examples/main?filepath=machine-learning.ipynb

LICENSE
-------

New BSD. See `License File <https://github.com/dask/dask-ml/blob/main/LICENSE.txt>`__.

.. _documentation: https://dask.org
.. |Build Status| image:: https://github.com/dask/dask-ml/workflows/CI/badge.svg?branch=main
   :target: https://github.com/dask/dask-ml/actions?query=workflow%3A%22CI%22
.. |Azure Pipelines| image:: https://dev.azure.com/dask-dev/dask/_apis/build/status/dask.dask-ml?branchName=main
   :target: https://dev.azure.com/dask-dev/dask/_build/latest?definitionId=1&branchName=main
.. |Coverage| image:: https://codecov.io/gh/dask/dask-ml/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/dask/dask-ml/branch/main
   :alt: Coverage status
.. |Doc Status| image:: https://readthedocs.org/projects/ml/badge/?version=latest
   :target: https://ml.dask.org/
   :alt: Documentation Status
.. |Discourse| image:: https://img.shields.io/discourse/users?logo=discourse&server=https%3A%2F%2Fdask.discourse.group
   :alt: Discuss Dask-related things and ask for help
   :target: https://dask.discourse.group
.. |Version Status| image:: https://img.shields.io/pypi/v/dask-ml.svg
   :target: https://pypi.python.org/pypi/dask-ml/
.. |NumFOCUS| image:: https://img.shields.io/badge/powered%20by-NumFOCUS-orange.svg?style=flat&colorA=E1523D&colorB=007D8A
   :target: https://www.numfocus.org/
